/************************************************************************

  Example code for reading SMF files

  $Id: smf.cxx,v 1.2 2001/02/26 03:36:55 garland Exp $

 ************************************************************************/

#include "smf.h"
#include <gfx/script.h>
#include <gfx/geom3d.h>


static TriMesh *current_mesh = NULL;

static int script_v(const char *op, char *argline, Scripting *)
{
    Vec3 v;

    if(string_shift_numbers(&argline, v, 3)<3) return SCRIPT_ERR_SYNTAX;
    current_mesh->vertex.push_back(v);
    return SCRIPT_OK;
}

static int script_f(const char *op, char *argline, Scripting *)
{
    Face f;

    if(string_shift_numbers(&argline, f, 3)<3) return SCRIPT_ERR_SYNTAX;

    // Input indices are numbered from 1.  Subtract 1 to get 0-based
    // indices ala C++ arrays.
    f[0] -= 1; f[1] -= 1; f[2] -= 1;
    current_mesh->face.push_back(f);

    const Vec3& v1 = current_mesh->vertex[f[0]];
    const Vec3& v2 = current_mesh->vertex[f[1]];
    const Vec3& v3 = current_mesh->vertex[f[2]];
    Vec3 n = triangle_normal(v1, v2, v3);
    current_mesh->normal.push_back(n);
    
    return SCRIPT_OK;
}

static script_defn handlers[] =
{
    {"v", script_v},
    {"f", script_f},
};

REGISTER_COMMANDS(handlers);

TriMesh *read_smf_object(const char *filename)
{
    script_do_file(filename);
    TriMesh *m = current_mesh;
    current_mesh = NULL;
    return m;
}
